ApiRepo class

Constructors

ApiRepo()
factory

Properties

client ↔ Client
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
prefs ↔ GetStorage
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(MessageModel request) → Future<MessageModel>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited